% createMachFilter: Creates MACH filter for given images.
%
% Usage: [filter] = 
%   createMachFilter(imgs, fimgs, s, delta)
%
% 'fimgs'       - Fourier transforms of training images.
% 's'           - Size of side of image.
% 'delta'       - Delta value defined for false class training. Usually
%                   between 0.05 and 0.005
%
% 'filter'      - The filters

function [filter] = createMachFilter(fimgs, s, delta)

% Compute mean images
mfIm = mean(fimgs,2);

% Subtract mean and compute sx vector.
dif = bsxfun(@minus,fimgs,mfIm);
sx = mean(conj(dif) .* dif,2);

% sx = 0;
% for i = 1 : size(fimgs,2)
%     dif = fimgs(:,i) - mfIm;
%     
%     sx = sx + (conj(dif) .* dif);
% end
% sx = sx / size(fimgs,2);

delta = delta .* ones(s*s,1);

filter = (1./(sx+delta)) .* mfIm;

if sum(sum(isreal(filter))) == length(filter)
    imagesc(reshape(filter, [s s])); colormap('gray');
end