% This script runs all necessary operations for MACH Filter Testing and
% Training.

% Training images should be placed in proj2data folder.
% Testing images should be placed in proj2test folder.

clc;
clear;
close all;

% Declare data paths
imPath = '../proj2data';
testImPath = '../proj2test';

resPath = '../results';

mkdir(resPath);

readFromFile = 01;
verbose = 1;

% Size of images (just one side)
% I crop the images to eliminate a lot of the black space...
s = 128-2*20+1;

% Delta value for false class
delta = 0.05;

% Determines what part of the frequency response to use when reading data
% 0 - Whole Response
% 1 - Phase
% 2 - Magnitude
useMagPhase = 1;

% Ranges for filter design. Define for Elvations and Azimuths...
filtSet = {
    % Elevation Ranges
    {[0 15] [18 33] [36 51] [54 69] [72 90]} 
    
    % Azimuth Ranges
    {[0 9] [12 21] [24 33] [36 45] [48 57] [60 69] [72 81] [84 93]  ...
     [96 105] [108 117] [120 129] [132 141] [144 153] [156 165] ...
     [168 177] [180 189] [192 201] [204 213] [216 225] [228 237] ...
     [240 249] [252 261] [264 273] [276 285] [288 297] [300 309] ...
     [312 321] [324 333] [336 345] [348 357]}
};

filters = [];
filtLab = [];
if readFromFile
    for i = 1 : length(filtSet{1})
        for j = 1 : length(filtSet{2})
            % Read training images from file
            [imgs, fimgs] = readFiles(imPath, filtSet{1}{i}, ...
                                        filtSet{2}{j}, useMagPhase);

            % Create filter for current training images
            [filt] = createMachFilter2(fimgs, fimgs, s, delta);

            filtLab = [filtLab; filtSet{1}{i}, filtSet{2}{j}];
            filters = [filters filt];
        end
    end
    
    save trainInfo.mat filtLab filters imgs fimgs
else
    % Load training images and filters from file...
    load trainInfo.mat
end

% Read testing images.
[testImg, testfimg, testLabs] = readAllFiles(testImPath, useMagPhase);


count = 0;
temp = zeros(size(testfimg,2),1);
for i = 1 : size(testfimg,2)
    response = [];
    
    % Compute response of test image w.r.t. each filter.
    for j = 1 : size(filters,2)
        res = filters(:,j)' * testfimg(:,i);
        response = [response res];
    end
    
    % Select maximum response as best match.
    [y, ind] = max(response);
    
    curE = testLabs(i, 1);
    curA = testLabs(i, 2);

    % Determine if best match is the correct match and count number
    % correct.
    if curE >= filtLab(ind,1) && curE <= filtLab(ind,2) && ...
            curA >= filtLab(ind,3) && curA <= filtLab(ind,4)
        count  =  count + 1;
        temp(i) = 1;
        
        % Visualization of result
        if verbose
            curE, curA, filtLab(ind,:)

            figure;
            colormap(gray);

            subplot(1,3,1);
            imagesc(reshape(filters(:,ind), [s s])); title('MACH Filter');

            subplot(1,3,2);
            imagesc(reshape(testfimg(:,i), [s s])); title('Phase');

            subplot(1,3,3);
            imagesc(reshape(testImg(:,i), [s s])); title('Test Image');
            
            fname = sprintf('%s/result%.3da.jpg', resPath, i);
            print(gcf, '-djpeg99', fname);

            figure;
            sm = 40;            
            
            subplot(1,2,1);
            im = reshape(filters(:,ind), [s s]);
            im = im(1+sm:end-sm,1+sm:end-sm);
            imagesc(im); colormap(gray);
            
            subplot(1,2,2);
            im = reshape(testfimg(:,i), [s s]);
            im = im(1+sm:end-sm,1+sm:end-sm);
            imagesc(im); colormap(gray);

            % Save result to file
            fname = sprintf('%s/result%.3db.jpg', resPath, i);
            print(gcf, '-djpeg99', fname);
            
%             pause;
            close all;
        end
    end
end

close all;

% Compute accuracy.
accuracy = count / size(testfimg,2) * 100;
disp(['Accuracy: ' num2str(accuracy) '%']);