% readAllFiles: Reads all of the tank images within a folder.
%
% Usage: [imgs, fimgs, labels] = 
%   readAllFiles(imPath, useMagPhase)
%
% 'imPath'          - Image path (directory).
% 'useMagPhase'     - Which part of fft conversion to use.
%                       0: Whole
%                       1: Phase
%                       2: Magnitude
%
% 'image'       - Images read.
% 'fimages'     - Frequency domain verison of images.
% 'labels'      - Elevation and Azimuth value for each read image.

function [imgs, fimgs, labels] = readAllFiles(imPath, useMagPhase)

files = dir([imPath '/*.is4']);

imgs = [];
fimgs = [];
labels = [];
for i =  1 : length(files)
    % Open file and format it.
    fname = [imPath '/' files(i).name];

    fid = fopen(fname, 'r');
    im = fread(fid, [1 512*512], 'ubit8');
    fclose(fid);
    im = im(129:end);
    im = reshape(im, [100 100])';
    im = imresize(im, [128 128], 'bicubic');
    
    % Store elevation and azimuth value of current image.
    labs = sscanf(files(i).name, 'E%da%d.is4')';
    labels = [labels; labs];
    
    % Crop image
    val = 20;
    im = im(val:end-val,val:end-val);
    
    imgs = [imgs, im(:)];

    % Compute Fourier transform and store defined part.
    fim = fftshift(fft2(im));
    
    if useMagPhase == 1
        fimgs = [fimgs, angle(fim(:))];
    elseif useMagPhase == 2
        fimgs = [fimgs, abs(fim(:))];
    else
        fimgs = [fimgs, fim(:)];
    end
end

return