% readFiles: Reads files within elevation and azimuth range defined.
%
% Usage: [images, fimages] = 
%   readFiles(imPath, elevationRange, azimuthRange, useMagPhase)
%
% 'imPath'          - Image path (directory).
% 'elevationRange'  - Range of elevation values.
% 'azimuthRange'    - Range of azimuth values.
% 'useMagPhase'     - Which part of fft conversion to use.
%                       0: Whole
%                       1: Phase
%                       2: Magnitude
%
% 'image'       - Images read.
% 'fimages'     - Frequency domain verison of images.

function [images, fimages] = readFiles(imPath, elevationRange, ...
                                        azimuthRange, useMagPhase)

images = [];
fimages = [];

for i = elevationRange(1): 3 : elevationRange(2)
    for j = azimuthRange(1): 3 : azimuthRange(2)
        
        % Format current elevation and azimuth integer to text to open the
        % file.
        
        if(i < 10)
            elev = ['0' num2str(i)];
        else
            elev = num2str(i);
        end
        
        if i == 0
            if(j < 10)
                azi = ['00' num2str(j)];
            elseif (j < 100)
                azi = ['0' num2str(j)];
            else
                azi = num2str(j);
            end
        else
            azi = num2str(j);
        end
        
        fname = [imPath '/' 'E' elev 'a' azi '.is4'];
        
        fid = fopen(fname, 'r');
        
        if fid == -1
            continue;
        end
        
        
        % Read image
        im = fread(fid, [1 512*512], 'ubit8');
        fclose(fid);
        im = im(129:end);
        im = reshape(im, [100 100])';
        im = imresize(im, [128 128], 'bicubic');
        
        % Crop Image
        val = 20;
        im = im(val:end-val,val:end-val);
        
        images = [images, im(:)];

        % Compute Fourier transform of image
        fim = fftshift(fft2(im));
        
        % Store transformation (phase, magnitude, or whole)
        if useMagPhase == 1
            fimages = [fimages, angle(fim(:))];
        elseif useMagPhase == 2
            fimages = [fimages, abs(fim(:))];
        else
            fimages = [fimages, fim(:)];
        end
    end
end